//
//  DialogDemoView.swift
//  MoreComponentsUI
//
//  Created by Joseph N. Gregg on 10/14/24.
//

import Foundation
import SwiftUI

struct DialogDemoView: View {
    @State var didIt = false
    @State var showConfirmation = false
    let colors = ["red","green","blue"]
    @State var favoriteColor = "red"
    @State var showSheet = false
    
    var body: some View {
        VStack {
            Spacer()
            if didIt == false {
                Button("Do It!") {
                    showConfirmation = true
                }.buttonStyle(.bordered)
                 .confirmationDialog("Confirm it", isPresented: $showConfirmation) {
                    Button("OK") { didIt = true }
                    Button("Cancel", role: .cancel) { }
                } message: {
                    Text("Are you sure you want to do it?")
                }
            } else {
                Text("You have done it.")
            }
            Spacer()
            Text("Your favorite color is \(favoriteColor).")
            Button("Change it!") { showSheet = true }
                .buttonStyle(.bordered)
                .sheet(isPresented: $showSheet) {
                    ColorSheet(choices:colors,selected:favoriteColor,finalChoice:$favoriteColor)
                }
            Spacer()
        }
    }
}

struct ColorSheet : View {
    @Environment(\.dismiss) private var dismiss

    var choices : [String]
    @State var selected : String
    @Binding var finalChoice : String
    
    var body : some View {
        VStack {
            Text("Select a new color.")
            Picker("Favorite color",selection:$selected) {
                ForEach(choices,id:\.self) { choice in Text(choice) }
            }.pickerStyle(.segmented)
            HStack {
                Button("Cancel") {
                    dismiss()
                }
                Spacer()
                Button("Confirm") {
                    finalChoice = selected
                    dismiss()
                }
            }
        }.padding()
    }
}
