//
//  Photos.swift
//  MoreComponentsUI
//
//  Created by Joe Gregg on 10/11/24.
//

import Foundation
import PhotosUI
import SwiftUI

struct PhotosView: View {
    @State private var selectedItem: PhotosPickerItem?
    @State private var selectedImage: Image?

    var body: some View {
        VStack {
            Spacer()
            PhotosPicker("Select image", selection: $selectedItem, matching: .images)
                .buttonStyle(.bordered)
            
            if let image = selectedImage {
                image.resizable()
                    .scaledToFit()
                    .frame(width: 300, height: 300)
                Spacer()
            } else {
                Spacer()
                Image(systemName:"person").resizable().frame(width: 150,height: 150)
                Spacer()
            }
        }
        .onChange(of: selectedItem) {
            Task {
                if let loaded = try? await selectedItem?.loadTransferable(type: Image.self) {
                    selectedImage = loaded
                }
            }
        }
    }
}
